pub fn create_fast_parser() -> FastStreamingParserExpand description
Create a fast streaming parser with optimal configuration for performance
pub fn create_fast_parser() -> FastStreamingParserCreate a fast streaming parser with optimal configuration for performance